==> mktcenter-service-1.0.0-vg-20210617.095527-39-sources.jar: com/bizvane/mktcenterservice/models/vo/TaskVO.java <==
package com.bizvane.mktcenterservice.models.vo;


import com.bizvane.mktcenterservice.models.po.MktTaskPO;

import java.math.BigDecimal;

/**
 * @author chen.li
 * @date on 2018/7/17 9:41
 * @description
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public class TaskVO extends MktTaskPO {
    //有过期券  为true   没有为false
   private Boolean couponIsOrNo=false;
    /**
     * 1.获取所有数据
     * 2.获取启用的数据
     * 3.获取禁用的数据
     */
    private  Integer  showType;
    private  Long  brandId;
//    //立即发送：1是，0否
//    private Boolean sendImmediately;
//    //开始发送时间
//    private Date sendTime;
    //门店限制名单
    private String storeLimitList;
    //门店限制类型：1黑名单，2白名单
    private Integer storeLimitType;
    //门店限制状态：0不限制，1限制
    private Boolean isStoreLimit;
    /**
     * 只读. 任务描述. task_info
     * @mbg.generated  2018-07-14 13:26:02
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务描述", name = "taskInfo", required = false, example = "")
    private String taskInfo;
    /**
     * 只读. 任务列表图片，多张逗号分隔. task_list_img
     * @mbg.generated  2018-07-14 13:26:02
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务列表图片，多张逗号分隔", name = "taskListImg", required = false, example = "")
    private String taskListImg;
    /**
     * 只读. 任务详情图片. task_detail_img
     * @mbg.generated  2018-07-14 13:26:02
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务详情图片", name = "taskDetailImg", required = false, example = "")
    private String taskDetailImg;

    /**
     * 只读. 邀请开卡人数. invite_num
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "邀请开卡人数", name = "inviteNum", required = false, example = "")
    private Integer inviteNum;

    /**
     * 1.单条件奖励 2.循环奖励
     */
    @io.swagger.annotations.ApiModelProperty(value = "1.单条件奖励 2.循环奖励", name = "rewardType", required = false, example = "")
    private Integer rewardType;

    /**
     * 最大邀请成功人数限制
     */
    @io.swagger.annotations.ApiModelProperty(value = "最大邀请成功人数限制", name = "maxInviteNum", required = false, example = "")
    private Integer maxInviteNum;

    /**
     * 只读. 任务条件/订单来源限制：0全部类型，1线下订单，2微商城订单. order_source
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/订单来源限制：0全部类型，1线下订单，2微商城订单", name = "orderSource", required = false, example = "")
    private Integer orderSource;
    /**
     * 只读. 任务条件/累计消费金额. consume_amount
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/累计消费金额", name = "consumeAmount", required = false, example = "")
    private BigDecimal consumeAmount;
    /**
     * 只读. 任务条件/累计消费次数. consume_times
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/累计消费次数", name = "consumeTimes", required = false, example = "")
    private Integer consumeTimes;

    /**
     * 只读. 需要完善的字段code，逗号分隔. property_code
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "需要完善的字段code，逗号分隔", name = "propertyCode", required = false, example = "")
    private String propertyCode;
    private String propertyName;
    /**
     * 只读. 任务条件/分享次数. share_times
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/分享次数", name = "shareTimes", required = false, example = "")
    private Integer shareTimes;
    /**
     * 只读. 任务条件/分享的链接类型：1站内链接，2自定义链接. share_url_type
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/分享的链接类型：1站内链接，2自定义链接", name = "shareUrlType", required = false, example = "")
    private Integer shareUrlType;

    @io.swagger.annotations.ApiModelProperty(value = "任务条件/需要分享的链接名称", name = "shareUrlName", required = false, example = "")
    private String shareUrlName;
    /**
     * 只读. 任务条件/需要分享的链接. share_url
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/需要分享的链接", name = "shareUrl", required = false, example = "")
    private String shareUrl;

    /**
     * 调查问卷模板code
     */
    private String templateCode;

    private String templateName;

    /**
     * 受邀人成功开卡奖励开关 1=开启;0=关闭
     */
    @io.swagger.annotations.ApiModelProperty(value = "受邀人成功开卡奖励开关 1=开启;0=关闭", name = "newMemberAward", required = false, example = "")
    private Boolean newMemberAward;

    /**
     * 受邀人成功开卡赠送积分数值
     */
    @io.swagger.annotations.ApiModelProperty(value = "受邀人成功开卡赠送积分数值", name = "newMemberPoints", required = false, example = "")
    private Integer newMemberPoints;

    @io.swagger.annotations.ApiModelProperty(value = "受邀人成功开卡赠送礼包id", name = "newMemberMktGiftBagId", required = false, example = "")
    private Long newMemberMktGiftBagId;

    //受邀人成功开卡有过期券  为true   没有为false
    @io.swagger.annotations.ApiModelProperty(value = "受邀人成功开卡有过期券  为true   没有为false", name = "newMemberCouponIsOrNo", required = false, example = "")
    private Boolean newMemberCouponIsOrNo=false;

    public String getTaskInfo() {
        return taskInfo;
    }

    public void setTaskInfo(String taskInfo) {
        this.taskInfo = taskInfo;
    }

    public String getTaskListImg() {
        return taskListImg;
    }

    public void setTaskListImg(String taskListImg) {
        this.taskListImg = taskListImg;
    }

    public String getTaskDetailImg() {
        return taskDetailImg;
    }

    public void setTaskDetailImg(String taskDetailImg) {
        this.taskDetailImg = taskDetailImg;
    }

    public Integer getInviteNum() {
        return inviteNum;
    }

    public void setInviteNum(Integer inviteNum) {
        this.inviteNum = inviteNum;
    }

    public Integer getOrderSource() {
        return orderSource;
    }

    public void setOrderSource(Integer orderSource) {
        this.orderSource = orderSource;
    }

    public BigDecimal getConsumeAmount() {
        return consumeAmount;
    }

    public void setConsumeAmount(BigDecimal consumeAmount) {
        this.consumeAmount = consumeAmount;
    }

    public Integer getConsumeTimes() {
        return consumeTimes;
    }

    public void setConsumeTimes(Integer consumeTimes) {
        this.consumeTimes = consumeTimes;
    }

    public String getPropertyCode() {
        return propertyCode;
    }

    public void setPropertyCode(String propertyCode) {
        this.propertyCode = propertyCode;
    }

    public Integer getShareTimes() {
        return shareTimes;
    }

    public void setShareTimes(Integer shareTimes) {
        this.shareTimes = shareTimes;
    }

    public Integer getShareUrlType() {
        return shareUrlType;
    }

    public void setShareUrlType(Integer shareUrlType) {
        this.shareUrlType = shareUrlType;
    }

    public String getShareUrl() {
        return shareUrl;
    }

    public void setShareUrl(String shareUrl) {
        this.shareUrl = shareUrl;
    }

    public Integer getShowType() {
        return showType;
    }

    public void setShowType(Integer showType) {
        this.showType = showType;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getStoreLimitList() {
        return storeLimitList;
    }

    public void setStoreLimitList(String storeLimitList) {
        this.storeLimitList = storeLimitList;
    }

    public Integer getStoreLimitType() {
        return storeLimitType;
    }

    public void setStoreLimitType(Integer storeLimitType) {
        this.storeLimitType = storeLimitType;
    }

    public Boolean getIsStoreLimit() {
        return isStoreLimit;
    }

    public void setIsStoreLimit(Boolean isStoreLimit) {
        this.isStoreLimit = isStoreLimit;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public Boolean getCouponIsOrNo() {
        return couponIsOrNo;
    }

    public void setCouponIsOrNo(Boolean couponIsOrNo) {
        this.couponIsOrNo = couponIsOrNo;
    }

    public String getTemplateCode() {
        return templateCode;
    }

    public void setTemplateCode(String templateCode) {
        this.templateCode = templateCode;
    }

    public String getTemplateName() {
        return templateName;
    }

    public void setTemplateName(String templateName) {
        this.templateName = templateName;
    }

    public Integer getRewardType() {
        return rewardType;
    }

    public void setRewardType(Integer rewardType) {
        this.rewardType = rewardType;
    }

    public Integer getMaxInviteNum() {
        return maxInviteNum;
    }

    public void setMaxInviteNum(Integer maxInviteNum) {
        this.maxInviteNum = maxInviteNum;
    }

    public Boolean getNewMemberAward() {
        return newMemberAward;
    }

    public void setNewMemberAward(Boolean newMemberAward) {
        this.newMemberAward = newMemberAward;
    }

    public Integer getNewMemberPoints() {
        return newMemberPoints;
    }

    public void setNewMemberPoints(Integer newMemberPoints) {
        this.newMemberPoints = newMemberPoints;
    }

    public Long getNewMemberMktGiftBagId() {
        return newMemberMktGiftBagId;
    }

    public void setNewMemberMktGiftBagId(Long newMemberMktGiftBagId) {
        this.newMemberMktGiftBagId = newMemberMktGiftBagId;
    }

    public Boolean getNewMemberCouponIsOrNo() {
        return newMemberCouponIsOrNo;
    }

    public void setNewMemberCouponIsOrNo(Boolean newMemberCouponIsOrNo) {
        this.newMemberCouponIsOrNo = newMemberCouponIsOrNo;
    }

    public String getShareUrlName() {
        return shareUrlName;
    }

    public void setShareUrlName(String shareUrlName) {
        this.shareUrlName = shareUrlName;
    }
}

==> mktcenter-service-1.0.3-vg-20220616.105844-4-sources.jar: com/bizvane/mktcenterservice/models/vo/TaskVO.java <==
package com.bizvane.mktcenterservice.models.vo;


import com.bizvane.mktcenterservice.models.po.MktTaskPO;

import java.math.BigDecimal;

/**
 * @author chen.li
 * @date on 2018/7/17 9:41
 * @description
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public class TaskVO extends MktTaskPO {
    //有过期券  为true   没有为false
   private Boolean couponIsOrNo=false;
    /**
     * 1.获取所有数据
     * 2.获取启用的数据
     * 3.获取禁用的数据
     */
    private  Integer  showType;
    private  Long  brandId;
//    //立即发送：1是，0否
//    private Boolean sendImmediately;
//    //开始发送时间
//    private Date sendTime;
    //门店限制名单
    private String storeLimitList;
    //门店限制类型：1黑名单，2白名单
    private Integer storeLimitType;
    //门店限制状态：0不限制，1限制
    private Boolean isStoreLimit;
    /**
     * 只读. 任务描述. task_info
     * @mbg.generated  2018-07-14 13:26:02
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务描述", name = "taskInfo", required = false, example = "")
    private String taskInfo;
    /**
     * 只读. 任务列表图片，多张逗号分隔. task_list_img
     * @mbg.generated  2018-07-14 13:26:02
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务列表图片，多张逗号分隔", name = "taskListImg", required = false, example = "")
    private String taskListImg;
    /**
     * 只读. 任务详情图片. task_detail_img
     * @mbg.generated  2018-07-14 13:26:02
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务详情图片", name = "taskDetailImg", required = false, example = "")
    private String taskDetailImg;

    /**
     * 只读. 邀请开卡人数. invite_num
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "邀请开卡人数", name = "inviteNum", required = false, example = "")
    private Integer inviteNum;

    /**
     * 1.单条件奖励 2.循环奖励
     */
    @io.swagger.annotations.ApiModelProperty(value = "1.单条件奖励 2.循环奖励", name = "rewardType", required = false, example = "")
    private Integer rewardType;

    /**
     * 最大邀请成功人数限制
     */
    @io.swagger.annotations.ApiModelProperty(value = "最大邀请成功人数限制", name = "maxInviteNum", required = false, example = "")
    private Integer maxInviteNum;

    /**
     * 只读. 任务条件/订单来源限制：0全部类型，1线下订单，2微商城订单. order_source
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/订单来源限制：0全部类型，1线下订单，2微商城订单", name = "orderSource", required = false, example = "")
    private Integer orderSource;
    /**
     * 只读. 任务条件/累计消费金额. consume_amount
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/累计消费金额", name = "consumeAmount", required = false, example = "")
    private BigDecimal consumeAmount;
    /**
     * 只读. 任务条件/累计消费次数. consume_times
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/累计消费次数", name = "consumeTimes", required = false, example = "")
    private Integer consumeTimes;

    /**
     * 只读. 需要完善的字段code，逗号分隔. property_code
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "需要完善的字段code，逗号分隔", name = "propertyCode", required = false, example = "")
    private String propertyCode;
    private String propertyName;
    /**
     * 只读. 任务条件/分享次数. share_times
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/分享次数", name = "shareTimes", required = false, example = "")
    private Integer shareTimes;
    /**
     * 只读. 任务条件/分享的链接类型：1站内链接，2自定义链接. share_url_type
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/分享的链接类型：1站内链接，2自定义链接", name = "shareUrlType", required = false, example = "")
    private Integer shareUrlType;

    @io.swagger.annotations.ApiModelProperty(value = "任务条件/需要分享的链接名称", name = "shareUrlName", required = false, example = "")
    private String shareUrlName;
    /**
     * 只读. 任务条件/需要分享的链接. share_url
     * @mbg.generated  2018-07-25 16:02:16
     */
    @io.swagger.annotations.ApiModelProperty(value = "任务条件/需要分享的链接", name = "shareUrl", required = false, example = "")
    private String shareUrl;

    /**
     * 调查问卷模板code
     */
    private String templateCode;

    /**
     * 非会员调查问卷模板code
     */
    private String touristTemplateCode;

    private String templateName;
    /**
     * 非会员调查问卷模板名称
     */
    private String touristTemplateName;

    /**
     * 受邀人成功开卡奖励开关 1=开启;0=关闭
     */
    @io.swagger.annotations.ApiModelProperty(value = "受邀人成功开卡奖励开关 1=开启;0=关闭", name = "newMemberAward", required = false, example = "")
    private Boolean newMemberAward;

    /**
     * 受邀人成功开卡赠送积分数值
     */
    @io.swagger.annotations.ApiModelProperty(value = "受邀人成功开卡赠送积分数值", name = "newMemberPoints", required = false, example = "")
    private Integer newMemberPoints;

    @io.swagger.annotations.ApiModelProperty(value = "受邀人成功开卡赠送礼包id", name = "newMemberMktGiftBagId", required = false, example = "")
    private Long newMemberMktGiftBagId;

    //受邀人成功开卡有过期券  为true   没有为false
    @io.swagger.annotations.ApiModelProperty(value = "受邀人成功开卡有过期券  为true   没有为false", name = "newMemberCouponIsOrNo", required = false, example = "")
    private Boolean newMemberCouponIsOrNo=false;

    public String getTaskInfo() {
        return taskInfo;
    }

    public void setTaskInfo(String taskInfo) {
        this.taskInfo = taskInfo;
    }

    public String getTaskListImg() {
        return taskListImg;
    }

    public void setTaskListImg(String taskListImg) {
        this.taskListImg = taskListImg;
    }

    public String getTaskDetailImg() {
        return taskDetailImg;
    }

    public void setTaskDetailImg(String taskDetailImg) {
        this.taskDetailImg = taskDetailImg;
    }

    public Integer getInviteNum() {
        return inviteNum;
    }

    public void setInviteNum(Integer inviteNum) {
        this.inviteNum = inviteNum;
    }

    public Integer getOrderSource() {
        return orderSource;
    }

    public void setOrderSource(Integer orderSource) {
        this.orderSource = orderSource;
    }

    public BigDecimal getConsumeAmount() {
        return consumeAmount;
    }

    public void setConsumeAmount(BigDecimal consumeAmount) {
        this.consumeAmount = consumeAmount;
    }

    public Integer getConsumeTimes() {
        return consumeTimes;
    }

    public void setConsumeTimes(Integer consumeTimes) {
        this.consumeTimes = consumeTimes;
    }

    public String getPropertyCode() {
        return propertyCode;
    }

    public void setPropertyCode(String propertyCode) {
        this.propertyCode = propertyCode;
    }

    public Integer getShareTimes() {
        return shareTimes;
    }

    public void setShareTimes(Integer shareTimes) {
        this.shareTimes = shareTimes;
    }

    public Integer getShareUrlType() {
        return shareUrlType;
    }

    public void setShareUrlType(Integer shareUrlType) {
        this.shareUrlType = shareUrlType;
    }

    public String getShareUrl() {
        return shareUrl;
    }

    public void setShareUrl(String shareUrl) {
        this.shareUrl = shareUrl;
    }

    public Integer getShowType() {
        return showType;
    }

    public void setShowType(Integer showType) {
        this.showType = showType;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getStoreLimitList() {
        return storeLimitList;
    }

    public void setStoreLimitList(String storeLimitList) {
        this.storeLimitList = storeLimitList;
    }

    public Integer getStoreLimitType() {
        return storeLimitType;
    }

    public void setStoreLimitType(Integer storeLimitType) {
        this.storeLimitType = storeLimitType;
    }

    public Boolean getIsStoreLimit() {
        return isStoreLimit;
    }

    public void setIsStoreLimit(Boolean isStoreLimit) {
        this.isStoreLimit = isStoreLimit;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public Boolean getCouponIsOrNo() {
        return couponIsOrNo;
    }

    public void setCouponIsOrNo(Boolean couponIsOrNo) {
        this.couponIsOrNo = couponIsOrNo;
    }

    public String getTemplateCode() {
        return templateCode;
    }

    public void setTemplateCode(String templateCode) {
        this.templateCode = templateCode;
    }

    public String getTemplateName() {
        return templateName;
    }

    public void setTemplateName(String templateName) {
        this.templateName = templateName;
    }

    public Integer getRewardType() {
        return rewardType;
    }

    public void setRewardType(Integer rewardType) {
        this.rewardType = rewardType;
    }

    public Integer getMaxInviteNum() {
        return maxInviteNum;
    }

    public void setMaxInviteNum(Integer maxInviteNum) {
        this.maxInviteNum = maxInviteNum;
    }

    public Boolean getNewMemberAward() {
        return newMemberAward;
    }

    public void setNewMemberAward(Boolean newMemberAward) {
        this.newMemberAward = newMemberAward;
    }

    public Integer getNewMemberPoints() {
        return newMemberPoints;
    }

    public void setNewMemberPoints(Integer newMemberPoints) {
        this.newMemberPoints = newMemberPoints;
    }

    public Long getNewMemberMktGiftBagId() {
        return newMemberMktGiftBagId;
    }

    public void setNewMemberMktGiftBagId(Long newMemberMktGiftBagId) {
        this.newMemberMktGiftBagId = newMemberMktGiftBagId;
    }

    public Boolean getNewMemberCouponIsOrNo() {
        return newMemberCouponIsOrNo;
    }

    public void setNewMemberCouponIsOrNo(Boolean newMemberCouponIsOrNo) {
        this.newMemberCouponIsOrNo = newMemberCouponIsOrNo;
    }

    public String getShareUrlName() {
        return shareUrlName;
    }

    public void setShareUrlName(String shareUrlName) {
        this.shareUrlName = shareUrlName;
    }

    public Boolean getStoreLimit() {
        return isStoreLimit;
    }

    public void setStoreLimit(Boolean storeLimit) {
        isStoreLimit = storeLimit;
    }

    public String getTouristTemplateCode() {
        return touristTemplateCode;
    }

    public void setTouristTemplateCode(String touristTemplateCode) {
        this.touristTemplateCode = touristTemplateCode;
    }

    public String getTouristTemplateName() {
        return touristTemplateName;
    }

    public void setTouristTemplateName(String touristTemplateName) {
        this.touristTemplateName = touristTemplateName;
    }
}
